@@ -1,11 +1,53 @@
 package Dist::Zilla::PluginBundle::Author::OALDERS;
-$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000005';
+$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000006';
 use Moose;
 use namespace::autoclean;
 
 use feature qw( say );
 
+use Dist::Zilla::Plugin::AutoPrereqs;
+use Dist::Zilla::Plugin::CPANFile;
+use Dist::Zilla::Plugin::CheckChangesHasContent;
+use Dist::Zilla::Plugin::ConfirmRelease;
+use Dist::Zilla::Plugin::ContributorsFile;
+use Dist::Zilla::Plugin::CopyFilesFromBuild;
+use Dist::Zilla::Plugin::ExecDir;
+use Dist::Zilla::Plugin::ExtraTests;
+use Dist::Zilla::Plugin::Git::Check;
+use Dist::Zilla::Plugin::Git::Commit;
+use Dist::Zilla::Plugin::Git::Contributors;
+use Dist::Zilla::Plugin::Git::GatherDir;
+use Dist::Zilla::Plugin::Git::Push;
+use Dist::Zilla::Plugin::Git::Tag;
+use Dist::Zilla::Plugin::GithubMeta;
+use Dist::Zilla::Plugin::InstallGuide;
+use Dist::Zilla::Plugin::License;
+use Dist::Zilla::Plugin::MAXMIND::TidyAll;
+use Dist::Zilla::Plugin::MakeMaker;
+use Dist::Zilla::Plugin::Manifest;
+use Dist::Zilla::Plugin::ManifestSkip;
+use Dist::Zilla::Plugin::MetaJSON;
+use Dist::Zilla::Plugin::MetaNoIndex;
+use Dist::Zilla::Plugin::MetaResources;
+use Dist::Zilla::Plugin::MetaYAML;
+use Dist::Zilla::Plugin::MinimumPerl;
+use Dist::Zilla::Plugin::PkgVersion;
+use Dist::Zilla::Plugin::Pod2Readme;
+use Dist::Zilla::Plugin::PodCoverageTests;
+use Dist::Zilla::Plugin::PodWeaver;
+use Dist::Zilla::Plugin::Prereqs;
+use Dist::Zilla::Plugin::PruneCruft;
+use Dist::Zilla::Plugin::ReadmeAnyFromPod;
+use Dist::Zilla::Plugin::ShareDir;
+use Dist::Zilla::Plugin::Test::CPAN::Changes;
+use Dist::Zilla::Plugin::Test::PodSpelling;
+use Dist::Zilla::Plugin::TestRelease;
+use Dist::Zilla::Plugin::Test::Synopsis;
+use Dist::Zilla::Plugin::Test::TidyAll;
+use Dist::Zilla::Plugin::TravisCI::StatusBadge;
+use Dist::Zilla::Plugin::UploadToCPAN;
 use List::AllUtils qw( first );
+use Pod::Elemental::Transformer::List;
 use Types::Path::Tiny qw( Path );
 use Types::Standard qw( ArrayRef Maybe Str );
 
@@ -34,10 +76,9 @@ has stopwords_file => (
 sub configure {
     my $self = shift;
 
-    my $readme      = 'README.md';
-    my @dirty_files = ( 'dist.ini', 'Changes', $readme );
-    my @from_build  = qw(INSTALL LICENSE META.json);
-    my @copy        = ( 'cpanfile', 'Makefile.PL', $readme );
+    my $readme     = 'README.md';
+    my @from_build = qw(INSTALL LICENSE META.json);
+    my @copy       = ( 'cpanfile', 'Makefile.PL', $readme );
 
     # Must come before Git::Commit
     $self->add_plugins('NextRelease');
@@ -53,7 +94,11 @@ sub configure {
         [ 'GithubMeta' => { issues => 1 } ],
         'ExtraTests',
         [ 'Git::GatherDir' => { exclude_filename => \@copy } ],
-        [ 'Git::Check' => { allow_dirty => [ @dirty_files, @from_build ] } ],
+        [
+            'Git::Check' => {
+                allow_dirty => [ 'dist.ini', 'Changes', @copy, @from_build ]
+            }
+        ],
         'Git::Commit',
         'Git::Contributors',
         'Git::Tag',
@@ -132,7 +177,7 @@ Dist::Zilla::PluginBundle::Author::OALDERS - A plugin bundle for distributions b
 
 =head1 VERSION
 
-version 0.000005
+version 0.000006
 
 =head2 configure
 
